pub enum ChapterLockingStatus {
Unlocked,
CompletedAndLocked,
NotUnlockedYet,
}Variants
Unlocked
Chapter is unlocked and exercises can be submitted.
CompletedAndLocked
Chapter content is accessible, but exercises are locked (chapter has been completed).
NotUnlockedYet
Chapter is locked because previous chapters are not completed.