pub async fn unlock_chapters_for_user(
conn: &mut PgConnection,
user_id: Uuid,
course_id: Uuid,
chapter_ids: &[Uuid],
) -> ModelResult<()>Expand description
Unlocks the provided chapters for a user within a course.
pub async fn unlock_chapters_for_user(
conn: &mut PgConnection,
user_id: Uuid,
course_id: Uuid,
chapter_ids: &[Uuid],
) -> ModelResult<()>Unlocks the provided chapters for a user within a course.